==> dpay_flutter-1.4.2.tar.gz: lib/CheckoutOptions.dart <==
import 'package:dpay_flutter/CustomerInfo.dart';

class DCheckoutOptions extends CustomerInfo{
  String _accessToken;
  String _environment;
  String _locale;
  String _siteName;
  String _orderId;
  String _themeColor;
  String _accentColor;
  String _currency;
  String _amount;
  String _paymentType;

  String get accessToken => _accessToken;

  set accessToken(String accessToken) {
    _accessToken = accessToken;
  }

  String get environment => _environment;

  set environment(String environment) {
    _environment = environment;
  }

  String get locale => _locale;

  set locale(String locale) {
    _locale = locale;
  }

  String get siteName => _siteName;

  set siteName(String site_name) {
    _siteName = site_name;
  }

  String get orderId => _orderId;

  set orderId(String order_id) {
    _orderId = order_id;
  }

  String get amount => _amount;

  set amount(String amount) {
    _amount = amount;
  }

  String get paymentType => _paymentType;

  set paymentType(String payment_type) {
    _paymentType = payment_type;
  }

  String get currency => _currency;

  set currency(String currency) {
    _currency = currency;
  }

  String get themeColor => _themeColor;

  set themeColor(String theme_color) {
    _themeColor = theme_color;
  }

  String get accentColor => _accentColor;

  set accentColor(String accent_color) {
    _accentColor = accent_color;
  }

  Map<String, String> toMap() {
    return {
      'locale': locale,
      'siteName': siteName,
      'environment': environment,
      'orderId': orderId,
      'accessToken': accessToken,
      'amount': amount,
      'currency': currency,
      'customerId': customerId,
      'customerEmail': customerEmail,

      'payment_type': paymentType,
      'customerGivenName': customerGivenName,
      'customerMobile': customerMobile,
      "customerAddressLine1": customerAddressLine1,
      "customerAddressLine2": customerAddressLine2,
      "customerCity": customerCity,
      "customerRegion": customerRegion,
      "customerCountry": customerCountry,
      "customerPostalCode": customerPostalCode,
      "label": label,
      "receiverName": receiverName,
      "receiverPhone": receiverPhone,
      "landmark": landmark,

      'themeColor': themeColor,
      'accentColor': accentColor
    };
  }
}

==> dpay_flutter-1.4.9.tar.gz: lib/CheckoutOptions.dart <==
import 'package:dpay_flutter/CustomerInfo.dart';

class DCheckoutOptions extends CustomerInfo {
  String _accessToken;
  String _environment;
  String _locale;
  String _siteName;
  String _orderId;
  String _themeColor;
  String _accentColor;
  String _currency;
  String _amount;
  String _paymentType;
  bool _darkMode;

  String get accessToken => _accessToken;

  set accessToken(String accessToken) {
    _accessToken = accessToken;
  }

  String get environment => _environment;

  set environment(String environment) {
    _environment = environment;
  }

  String get locale => _locale;

  set locale(String locale) {
    _locale = locale;
  }

  String get siteName => _siteName;

  set siteName(String site_name) {
    _siteName = site_name;
  }

  String get orderId => _orderId;

  set orderId(String order_id) {
    _orderId = order_id;
  }

  String get amount => _amount;

  set amount(String amount) {
    _amount = amount;
  }

  String get paymentType => _paymentType;

  set paymentType(String payment_type) {
    _paymentType = payment_type;
  }

  String get currency => _currency;

  set currency(String currency) {
    _currency = currency;
  }

  String get themeColor => _themeColor;

  set themeColor(String theme_color) {
    _themeColor = theme_color;
  }

  String get accentColor => _accentColor;

  set accentColor(String accent_color) {
    _accentColor = accent_color;
  }

  bool get darkMode => _darkMode;

  set darkMode(bool dark_mode) {
    _darkMode = dark_mode;
  }

  Map<String, Object> toMap() {
    return {
      'locale': locale,
      'siteName': siteName,
      'environment': environment,
      'orderId': orderId,
      'accessToken': accessToken,
      'amount': amount,
      'currency': currency,
      'customerId': customerId,
      'customerEmail': customerEmail,
      'payment_type': paymentType,
      'customerGivenName': customerGivenName,
      'customerMobile': customerMobile,
      "customerAddressLine1": customerAddressLine1,
      "customerAddressLine2": customerAddressLine2,
      "customerCity": customerCity,
      "customerRegion": customerRegion,
      "customerCountry": customerCountry,
      "customerPostalCode": customerPostalCode,
      "label": label,
      "receiverName": receiverName,
      "receiverPhone": receiverPhone,
      "landmark": landmark,
      'themeColor': themeColor,
      'accentColor': accentColor,
      'darkMode': darkMode,
    };
  }
}
